@@ -175,7 +175,7 @@ class ControllerTestPlugin(TileBusProxyPlugin):
         """
         for i in range(0, len(data), 20):
             chunk = data[i:i+20]
-            err, = self.rpc(0x10, 0x0c, chunk, result_format="L")
+            err, = self.rpc(0x10, 0x0c, bytearray(chunk, 'utf-8'), result_format="L")
             if err != 0:
                 raise HardwareError("Error tracing data", error_code=err)
 
